==> apiconnect-ui-projects-2.0.11.tgz: package/src/module.js <==
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
'use strict';

var angular = require('angular');
require('eventsource-polyfill');
var injectCss = require('inject-css');

angular.module('apic.projects', [
  'pascalprecht.translate',
  'ui.bootstrap',
  'apim.loopback'
])
  .config(function(){
    injectCss(require('./styles/main.styl'));
  })
  .service('ProjectsServices', require('./projects-services'))
  .service('FileServices', require('./file-services'))
  .service('ConfigServices', require('./config-services'))
  .controller('NodeTreeController', require('./node-tree-controller'))
  .controller('NodeItemController', require('./node-item-controller'))
  .controller('AddLoopbackProjectController', require('./add-loopback-project-controller'))
  .controller('AddOpenApiProjectController', require('./add-openapi-project-controller'))
  .controller('AddProjectController', require('./add-project-controller'))
  .controller('LoopbackSettingsController', require('./loopback-settings-controller'))
  .controller('OpenApiSettingsController', require('./openapi-settings-controller'))
  .controller('ProjectNodeItemController', require('./project-node-item-controller'))
  .controller('ProjectNodesController', require('./project-nodes-controller'))
  .controller('ProjectsFilepickerController', require('./projects-filepicker-controller'))
  .directive('apimProjectItem', require('./project-item-directive'))
  .directive('apimProjectsFilepicker', require('./projects-filepicker-directive'))
  .directive('apimNodeTree', require('./node-tree-directive'))
  .directive('apimNodeItem', require('./node-item-directive'))
  .directive('apimProjectNodes', require('./project-nodes-directive'))
  .directive('apimProjectNodeItem', require('./project-node-item-directive'))
  .directive('apimProjectNav', require('./project-nav-directive'));

==> apiconnect-ui-projects-3.0.2.tgz: package/src/module.js <==
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
'use strict';

var angular = require('angular');
require('event-source-polyfill');
var injectCss = require('inject-css');

angular.module('apic.projects', [
  'pascalprecht.translate',
  'ui.bootstrap',
  'apim.loopback'
])
  .config(function(){
    injectCss(require('./styles/main.styl'));
  })
  .service('ProjectsServices', require('./projects-services'))
  .service('FileServices', require('./file-services'))
  .service('ConfigServices', require('./config-services'))
  .controller('NodeTreeController', require('./node-tree-controller'))
  .controller('NodeItemController', require('./node-item-controller'))
  .controller('AddLoopbackProjectController', require('./add-loopback-project-controller'))
  .controller('AddOpenApiProjectController', require('./add-openapi-project-controller'))
  .controller('AddProjectController', require('./add-project-controller'))
  .controller('LoopbackSettingsController', require('./loopback-settings-controller'))
  .controller('OpenApiSettingsController', require('./openapi-settings-controller'))
  .controller('ProjectNodeItemController', require('./project-node-item-controller'))
  .controller('ProjectNodesController', require('./project-nodes-controller'))
  .controller('ProjectsFilepickerController', require('./projects-filepicker-controller'))
  .directive('apimProjectItem', require('./project-item-directive'))
  .directive('apimProjectsFilepicker', require('./projects-filepicker-directive'))
  .directive('apimNodeTree', require('./node-tree-directive'))
  .directive('apimNodeItem', require('./node-item-directive'))
  .directive('apimProjectNodes', require('./project-nodes-directive'))
  .directive('apimProjectNodeItem', require('./project-node-item-directive'))
  .directive('apimProjectNav', require('./project-nav-directive'));
